@@ -2,12 +2,12 @@
  *                 Mathematical Object Library                 *
  *       Abaqus Conversion tools Library - Include File        *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2007,2008 COLLARD Christophe
- * copyright  2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2007,2008,2009 COLLARD Christophe
+ * copyright © 2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*! \namespace abaqus
@@ -40,11 +40,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2007, 2008 Christophe COLLARD \n
-	    copyright \htmlonly &#169; 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
-	    copyright \htmlonly &#169; 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
-    \version 2.0.0
-    \date 2007-2008
+    \author copyright \htmlonly &#169; \endhtmlonly 2007, 2008, 2009 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2007, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
+    \version 2.2.0
+    \date 2007-2009
     \bug none
     \warning none
 */
@@ -219,11 +219,11 @@ template <class T> void strain2vector (const tensor2<T>& strain, T* v)
 
   Let \f$ M \f$ be a matrix in  \f$ \mathbb{R}^3 \times \mathbb{R}^3 \f$. We define \f$ C \f$ the \f$ 4^\text{th} \f$ order tensor in \f$ \mathbb{R}^3 \times \mathbb{R}^3 \times \mathbb{R}^3 \times \mathbb{R}^3 \f$ such as \f$ C_{ijkl} = C_{jikl} = C_{ijlk} \f$ and
   \f$ C_{ij} = M_{ij} \f$, where we use the following notation for \f$ C \f$ indices \n
-  \f$ \begin{tabular}{| c | c | c | c | c | c | c | c |}
-  \hline $C_{pq} : p \equiv$ & 1 & 2 & \dots & n & n+1 & n+2 & \dots \\
-  \hline $C_{ijkl} : ij \equiv$ & 11 & 22 & \dots & nn & 12 & 13 & \dots \\
+  \f$ \begin{array}{| c | c | c | c | c | c | c | c |}
+  \hline C_{pq} : p \equiv & 1 & 2 & \dots & n & n+1 & n+2 & \dots \\
+  \hline C_{ijkl} : ij \equiv & 11 & 22 & \dots & nn & 12 & 13 & \dots \\
   \hline
-  \end{tabular}
+  \end{array}
   \f$
   \param mat matrix M
   \return C
@@ -278,11 +278,11 @@ template <class T> tensor4<T> matrix2symtensor (const matrix<T>& mat)
   Let \f$ C \f$ be a \f$ 4^\text{th} \f$ order tensor in \f$ \mathbb{R}^3 \times \mathbb{R}^3 \times \mathbb{R}^3 \times \mathbb{R}^3 \f$ such as \f$ C_{ijkl} = C_{jikl} = C_{ijlk} \f$.
   We define the matrix \f$ M \in \mathbb{R}^3 \times \mathbb{R}^3 \f$ such as \n
   \f$ M_{ij} = C_{ij} \f$, where we use the following notation for \f$ C \f$ indices \n
-  \f$ \begin{tabular}{| c | c | c | c | c | c | c | c |}
-  \hline $C_{pq} : p \equiv $ & 1 & 2 & \dots & n & n+1 & n+2 & \dots \\
-  \hline $C_{ijkl} : ij \equiv$ & 11 & 22 & \dots & nn & 12 & 13 & \dots \\
+  \f$ \begin{array}{| c | c | c | c | c | c | c | c |}
+  \hline C_{pq} : p \equiv & 1 & 2 & \dots & n & n+1 & n+2 & \dots \\
+  \hline C_{ijkl} : ij \equiv & 11 & 22 & \dots & nn & 12 & 13 & \dots \\
   \hline
-  \end{tabular}
+  \end{array}
   \f$
   \param tsr \f$ 4^\text{th} \f$ order tensor C
   \return M
