@@ -2,12 +2,12 @@
  *                 Mathematical Object Library                 *
  *           Conversion tools Library - Include File           *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006,2007,2008 COLLARD Christophe
- * copyright  2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2003,2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*! \namespace mol
@@ -40,11 +40,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2003, 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
-	    copyright \htmlonly &#169; 2003, 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
-	    copyright \htmlonly &#169; 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
-    \version 2.0.0
-    \date 2003-2008
+    \author copyright \htmlonly &#169; \endhtmlonly 2003, 2004, 2005, 2006, 2007, 2008, 2009 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2003, 2004, 2005, 2006, 2007, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
+    \version 2.2.0
+    \date 2003-2009
     \bug none
     \warning none
 */
@@ -143,7 +143,7 @@ template <class T> matrix<T> vector2matrix (const vector<T>& v, int rows, int co
 
 
 /*!
-  \brief Converts a vector into a symmetric \f$ 2^\text{nd} \f$ order.
+  \brief Converts a vector into a symmetric \f$ 2^\text{nd} \f$ order tensor.
 
   Let \f$ v \f$ be a vector of \f$ \mathbb{R}^n \f$. We define \f$ T \in \mathbb{R}^m \times \mathbb{R}^m \f$, with \f$ m = \frac{1}{2} (\sqrt{1+8n} - 1) \f$, by
   \f$ T = \left( \begin{matrix}
@@ -255,11 +255,11 @@ template <class T> tensor4<T> matrix2tensor (const matrix<T>& mat, int d1, int d
   \right.
   \f$ \n
   and where we use the following notation for \f$ C \f$ indices \n
-  \f$ \begin{tabular}{| c | c | c | c | c | c | c | c |}
-  \hline $C_{pq} : p \equiv$ & 1 & 2 & \dots & n & n+1 & n+2 & \dots \\
-  \hline $C_{ijkl} : ij \equiv$ & 11 & 22 & \dots & nn & 12 & 13 & \dots \\
+  \f$ \begin{array}{| c | c | c | c | c | c | c | c |}
+  \hline C_{pq} : p \equiv & 1 & 2 & \dots & n & n+1 & n+2 & \dots \\
+  \hline C_{ijkl} : ij \equiv & 11 & 22 & \dots & nn & 12 & 13 & \dots \\
   \hline
-  \end{tabular}
+  \end{array}
   \f$
   \param mat matrix M
   \return C
@@ -399,11 +399,11 @@ template <class T> vector<T> symtensor2vector (const symtensor2<T>& tsr)
   \right.
   \f$ \n
   and where we use the following notation for \f$ C \f$ indices \n
-  \f$ \begin{tabular}{| c | c | c | c | c | c | c | c |}
-  \hline $C_{pq} : p \equiv $ & 1 & 2 & \dots & n & n+1 & n+2 & \dots \\
-  \hline $C_{ijkl} : ij \equiv$ & 11 & 22 & \dots & nn & 12 & 13 & \dots \\
+  \f$ \begin{array}{| c | c | c | c | c | c | c | c |}
+  \hline C_{pq} : p \equiv & 1 & 2 & \dots & n & n+1 & n+2 & \dots \\
+  \hline C_{ijkl} : ij \equiv & 11 & 22 & \dots & nn & 12 & 13 & \dots \\
   \hline
-  \end{tabular}
+  \end{array}
   \f$
   \param tsr \f$ 4^\text{th} \f$ order tensor C
   \return M
