@@ -2,12 +2,12 @@
  *                 Mathematical Object Library                 *
  *          class function: declaration for functions          *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.0.1                   *
+ *                   GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006,2008 COLLARD Christophe
- * copyright  2005,2006,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2005,2006,2008,2009 COLLARD Christophe
+ * copyright © 2005,2006,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2005,2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*! \namespace mol
@@ -40,11 +40,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2008 Christophe COLLARD \n
-	    copyright \htmlonly &#169; 2005, 2006, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
-	    copyright \htmlonly &#169; 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
-    \version 2.0.1
-    \date 2005-2008
+    \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2008, 2009 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2005, 2006, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
+    \version 2.2.0
+    \date 2005-2009
     \bug none
     \warning under construction (an interpreter will be available later)
 */
@@ -173,11 +173,11 @@ template <class T> vector<T> function<T>::operator () (const vector<T>& x) const
   //  for (int i=0; i<dimension; i++)
   //    assert (x[i].dim());
 
-  if ((f[0])=="x") value[1] = power(x[1],2);
-  else if ((f[0])=="x/y") value[1] = power(x[1],2) / x[2];
+  if ((f[0])=="x²") value[1] = power(x[1],2);
+  else if ((f[0])=="x²/y") value[1] = power(x[1],2) / x[2];
   else if ((f[0])=="x*exp(x*y)") value[1] = x[1] * exp(x[1]*x[2]);
-  else if ((f[0])=="x/y*sin(z)") value[1] = power(x[1],2) / x[2] * sin(x[3]);
-  else if ((f[0])=="x*z*exp(yz)") value[1] = power(x[1],2) * power(x[3],2) * exp(x[2]*x[3]);
+  else if ((f[0])=="x²/y*sin(z)") value[1] = power(x[1],2) / x[2] * sin(x[3]);
+  else if ((f[0])=="x²*z²*exp(yz)") value[1] = power(x[1],2) * power(x[3],2) * exp(x[2]*x[3]);
   else if ((f[0])=="heterogeneites plastiques")
     { // partie heterogeneites plastiques
       // T nu = 0.3;
