@@ -2,14 +2,14 @@
  *                 Mathematical Object Library                 *
  *	      class matrix:  declarations for matrix	       *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  1995,1996,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008 COLLARD Christophe
- * copyright  2002,2003,2004 CREUSE Emmanuel
- * copyright  2003,2004 MERCIER Denis
- * copyright  2002,2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 1995,1996,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2002,2003,2004 CREUSE Emmanuel
+ * copyright © 2003,2004 MERCIER Denis
+ * copyright © 2002,2003,2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2002,2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*! \namespace mol
@@ -42,13 +42,13 @@
     </FONT>
     \endhtmlonly
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Christophe COLLARD \n
              copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004 Emmanuel CREUSE \n
 	     copyright \htmlonly &#169; \endhtmlonly 2003, 2004 Denis MERCIER \n
-	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
-	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
-    \version 2.0.0
-    \date 1995-2008
+	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
+    \version 2.2.0
+    \date 1995-2009
     \bug none
     \warning none
 */
@@ -611,7 +611,8 @@ template <class Tf> bool operator == (const matrix<Tf>& mat1, const matrix<Tf>&
 
   for (int i=1; i<=mat1.nbRows && result; i++)
     for (int j=1; (j<=mat1.nbColumns) && (result); j++)
-      result *= abs(mat1(i,j) - mat2(i,j)) < epsilon;    // where epsilon is the computer approximation
+      if (abs (mat1(i,j)) < epsilon) result *= abs (mat2(i,j)) < epsilon;
+      else result *= abs ((mat1(i,j) - mat2(i,j)) / mat1(i,j)) < epsilon;    // where epsilon is the computer approximation
 
   return result;
 }
