@@ -2,12 +2,12 @@
  *                   Mathematical Object Library                   *
  *  Class polynom : declaration for polynoms and its derivatives   *
  *                      simula+@metz.ensam.fr                      *
- *	               GNU/linux version 2.0.0                     *
+ *	               GNU/linux version 2.2.0                     *
  *              software under General Public License              *
  *******************************************************************
- * copyright  2002,2003,2004,2005,2006,2008 COLLARD Christophe
- * copyright  2002,2003,2004,2005,2006,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2002,2003,2004,2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2002,2003,2004,2005,2006,2008,2009 COLLARD Christophe
+ * copyright © 2002,2003,2004,2005,2006,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2002,2003,2004,2005,2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  *******************************************************************/
 
 /*! \namespace mol
@@ -40,11 +40,11 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2008 Christophe COLLARD \n
-	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
-	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
-    \version 2.0.0
-    \date 2002-2008
+    \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2008, 2009 Christophe COLLARD \n
+	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
+    \version 2.2.0
+    \date 2002-2009
     \bug none
     \warning none
 */
@@ -106,6 +106,7 @@ template <class T> class polynom : public vector<T>
     polynom (polynom<T>* P) : vector<T>(P) {}         // copy constructor with temporary objects
     ~polynom () {}                 // destructor
 
+    T* operator () () {return p;}
     void assign (int);  // allocates memory for the polynom but doen't initilize to zero its components (use it with great care)
     int dim () const {return 1;} // returns space dimension
     T& operator [] (int) const;  // returns the n_th coefficient of the polynom P(X) (coef in X^n)
@@ -135,9 +136,6 @@ template <class T> class polynom : public vector<T>
     template <class Tf> friend void order (polynom<Tf>&);
     template <class Tf> friend polynom<Tf> subvector (const polynom<Tf>&, int, int);
     template <class Tf> friend polynom<Tf> merge (const polynom<Tf>&, const polynom<Tf>&);
-
-    // mpi functions
-    template <class Tf> friend void broadcast (polynom<Tf>&, int);  // send vector on threads (see MPIOL++/broadcast.h)
 };
 
 
