@@ -2,15 +2,15 @@
  *                 Mathematical Object Library                 *
  *       class spmatrix : declarations for sparse matrix       *
  *                    simula+@metz.ensam.fr                    *
- *		     GNU/linux version 2.0.0                   *
+ *		     GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005 LAGOUCHE Sophie
- * copyright  2004,2005 CREUSE Emmanuel
- * copyright  2006 FACHE Damien
- * copyright  2006,2007,2008 COLLARD Christophe
- * copyright  2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2004,2005 LAGOUCHE Sophie
+ * copyright © 2004,2005 CREUSE Emmanuel
+ * copyright © 2006 FACHE Damien
+ * copyright © 2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*! \namespace mol
@@ -108,11 +108,11 @@
   \authors copyright \htmlonly &#169; \endhtmlonly 2004, 2005 Sophie LAGOUCHE \n
            copyright \htmlonly &#169; \endhtmlonly 2004, 2005 Emmanuel CREUSE \n
            copyright \htmlonly &#169; \endhtmlonly 2006 Damien FACHE \n
-           copyright \htmlonly &#169; \endhtmlonly 2006, 2007, 2008 Christophe COLLARD \n
-	   copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
-	   copyright \htmlonly &#169; 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
-  \version 2.0.0
-  \date 2004-2008
+           copyright \htmlonly &#169; \endhtmlonly 2006, 2007, 2008, 2009 Christophe COLLARD \n
+	   copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+	   copyright \htmlonly &#169; 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
+  \version 2.2.0
+  \date 2004-2009
   \bug none
   \warning none
 */
@@ -1330,7 +1330,8 @@ template <class Tf> bool operator == (const spmatrix<Tf>& mat1, const spmatrix<T
 	if (mat1.nbRowsElements[i] == mat2.nbRowsElements[i])
 	  { r = mat1.nbRowsElements[i];
 	    for (int j=1; j<=r && result; j++)
-	      result *= ( abs(mat1.mrows[i-1][j] - mat2(i,mat1.columns_position(i,j))) < epsilon );
+	      if (abs (mat1.mrows[i-1][j]) < epsilon) result *= abs (mat2(i,mat1.columns_position(i,j))) < epsilon;
+	      else result *= ( abs ((mat1.mrows[i-1][j] - mat2(i,mat1.columns_position(i,j))) / mat1.mrows[i-1][j]) < epsilon );
 	  }
 	else result = false;
     }
