@@ -2,14 +2,14 @@
  *                 Mathematical Object Library                 *
  *           class vector : declaration for vectors            *
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0	               *
+ *	             GNU/linux version 2.2.0	               *
  *            software under General Public License            *
  ***************************************************************
- * copyright  1994,1995,1996,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008 COLLARD Christophe
- * copyright  2002,2003,2004 CREUSE Emmanuel
- * copyright  2003,2004 MERCIER Denis
- * copyright  2002,2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 1994,1995,1996,1999,2000,2001,2002,2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2002,2003,2004 CREUSE Emmanuel
+ * copyright © 2003,2004 MERCIER Denis
+ * copyright © 2002,2003,2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2002,2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*! \namespace mol
@@ -45,13 +45,13 @@
     A vector is defined by its size and a pointer on the table of its coordinates. \n
     When the size of a vector is zero there is no table of coordinates attached to the pointer.
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 1994, 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 1994, 1995, 1996, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Christophe COLLARD \n
              copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004 Emmanuel CREUSE \n
 	     copyright \htmlonly &#169; \endhtmlonly 2003, 2004 Denis MERCIER \n
-	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007,2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
-	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
-    \version 2.0.0
-    \date 1994-2008
+	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
+	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
+    \version 2.2.0
+    \date 1994-2009
     \bug none
     \warning none
 */
@@ -84,10 +84,14 @@
 #include <math.h>
 #endif
 
-#if !defined(__STRING_H)
+#if !defined(__STRING)
 #include <string>
 #endif
 
+#if !defined(__STRING_H)
+#include<string.h>
+#endif
+
 #if !defined(__PARAMETERS_H)
 #include "parameters.h"
 #endif
@@ -121,6 +125,7 @@ template <class T> class vector
     int dim () const {return size;}       // returns the vector size
     friend bool operator ! (const vector<T>& v) {return !v.size;}
 
+    T* operator () () {return p;}
     T& operator [] (int) const;     // returns the address of an element
     virtual int operator = (int);   // allocates memory for the vector but doen't initilize to zero its components (use it with great care)
     virtual vector<T>& operator  = (const vector<T>&);
@@ -160,10 +165,6 @@ template <class T> class vector
     template <class Tf> friend vector<int> order (vector<Tf>&);          // vectors ordering from smallest to biggest
     template <class Tf> friend vector<Tf> subvector (const vector<Tf>&, int, int);      // extracts a sub-vector
     template <class Tf> friend vector<Tf> merge (const vector<Tf>&, const vector<Tf>&); // merges 2 vectors
-
-// mpi functions
-    template <class Tf> friend void broadcast (vector<Tf>&, int);  // send vector on threads (see MPIOL++/broadcast.h)
-    template <class Tf> friend void secure_broadcast (vector<Tf>&, int); // send vector on threads (see MPIOL++/secure broadcast.h)
 };
 
 
@@ -479,8 +480,11 @@ template <class Tf> bool operator == (const vector<Tf>& a, const vector<Tf>& b)
 {
   assert (a.size);		// a must exists
   bool Bool = (a.size==b.size);	// a & b must be in the same space
+
   for (int i=0; i<a.size && Bool; i++)
-    Bool *= abs(a.p[i]-b.p[i]) < epsilon;
+    if (abs (a.p[i]) < epsilon) Bool *= abs (b.p[i]) < epsilon;
+    else Bool *= abs ((a.p[i]-b.p[i]) / a.p[i]) < epsilon;
+
   return Bool;
 }
 
