@@ -5,8 +5,8 @@
  *            software under General Public License            *
  ***************************************************************
  * copyright  2006 COLLARD Christophe
- * copyright  2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright  2006 Laboratoire de Physique et Mécanique des Matériaux (LPMM - UMR 7554)
+ * copyright  2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
 #ifndef _parameters_h
@@ -16,10 +16,10 @@ using namespace std;
 #define DEBUG // debug mode
 //#define NDEBUG // exploitation mode
 
-double epsilon = 1e-9;
-double precision = 1e-12;
-//long double epsilon=1.e-12;     // precision machine pour approximer le zero
-//long double precision=1.e-15;   // precision machine pour les calculs
+//double epsilon = 1e-9;
+//double precision = 1e-12;
+long double epsilon=1.e-12;     // precision machine pour approximer le zero
+long double precision=1.e-15;   // precision machine pour les calculs
 
 #endif
 
