@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2007,2008 COLLARD Christophe
- * copyright  2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2007,2008,2009 COLLARD Christophe
+ * copyright © 2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -47,6 +47,10 @@
 #include <stdlib.h>
 #endif
 
+#if !defined(__COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__VECTORS_H)
 #include "MOL++/vectors.h"
 #endif
@@ -170,8 +174,8 @@ int test_abaqus_conversion_tools (int detail)
   cout << endl;
 
   cout << "============================================================== \n";
-  if (result) cout<< "             abaqus conversion tools test passed \n";
-  else cout << "             abaqus conversion tools test failed \n";
+  if (result) cout << green << "             abaqus conversion tools test passed" << reset;
+  else cout << red << "             abaqus conversion tools test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
