@@ -1,12 +1,12 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.0.0                   *
+ *                   GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006,2007 COLLARD Christophe
- * copyright  2003 CREUSE Emmanuel
- * copyright  2003,2004,2005,2006,2007 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2003,2004,2005,2006,2007,2009 COLLARD Christophe
+ * copyright © 2003 CREUSE Emmanuel
+ * copyright © 2003,2004,2005,2006,2007,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -52,6 +52,10 @@
 #include <time.h>
 #endif
 
+#if !defined(__COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__VECTORS_H)
 #include "MOL++/vectors.h"
 #endif
@@ -456,14 +460,14 @@ if (detail) cout << "-------------test for ssor with HILBERT matrix-------------
   
   iter = TAILLE ;     // max iterations
   spu = conjugate_gradient(sp,spb,spb,iter,1.e-15);
-  if (detail) cout << "gradient_conjugu : " << iter << " iterations :" ;
+  if (detail) cout << "gradient_conjugué : " << iter << " iterations :" ;
   if (detail) affiche ("", (spu==spv) && iter==43) ;
   else result *= (spu==spv && iter==43) ;
 
   iter = TAILLE ;
   parameter = 1.6 ;
   spu = ssor(parameter,sp,spb,spb,iter) ;
-  if (detail) cout << "gradient_conjugu prconditionn : " << iter << " iterations :" ;
+  if (detail) cout << "gradient_conjugué préconditionné : " << iter << " iterations :" ;
   if (detail) affiche ("", (spu==spv) && iter==24) ;
   else result *= (spu==spv && iter==24) ;
   
@@ -488,14 +492,14 @@ if (detail) cout << "-------------test for ssor with HILBERT matrix-------------
   
   iter = TAILLE ;
   spu = conjugate_gradient(sp,spb,spb,iter,1.e-15);
-  if (detail) cout << "gradient_conjugu : " << iter << " iterations :" ;
+  if (detail) cout << "gradient_conjugué : " << iter << " iterations :" ;
   if (detail) affiche ("", (spu==spv) && iter==91) ;
   else result *= (spu==spv && iter==91) ;
 
   iter = TAILLE ;
   parameter = 0.8 ;
   spu = ssor(parameter,sp,spb,spb,iter) ;
-  if (detail) cout << "gradient_conjugu prconditionn : " << iter << " iterations :" ;
+  if (detail) cout << "gradient_conjugué préconditionné : " << iter << " iterations :" ;
   if (detail) affiche ("", (spu==spv) && iter==71) ;
   else result *= (spu==spv && iter==71) ;
   
@@ -519,8 +523,8 @@ if (detail) cout << "-------------test for ssor with HILBERT matrix-------------
   */
 
   cout << "============================================================== \n";
-  if (result) cout<< "                linear systems test passed \n";
-  else cout << "                linear systems test failed \n";
+  if (result) cout << green << "                linear systems test passed" << reset;
+  else cout << red << "                linear systems test failed" << reset;
   cout << "============================================================== \n";
   return result;
 }
