@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.0.0                   *
+ *                   GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006,2007,2008 COLLARD Christophe
- * copyright  2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -39,6 +39,10 @@
 #include <iostream>
 #endif
 
+#if !defined(__COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__AFFICHE_h)
 #include "tests/affiche.h"
 #endif
@@ -101,8 +105,8 @@ bool test_maths (int detail)
   cout << endl;
 
   cout << "============================================================== \n";
-  if (result) cout<< "                    maths test passed \n";
-  else cout << "                    maths test failed \n";
+  if (result) cout << green << "                      maths test passed" << reset;
+  else cout << red << "                      maths test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
