@@ -1,13 +1,13 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.0.0                   *
+ *                   GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006,2007,2008 COLLARD Christophe
- * copyright  2003,2004 CREUSE Emmanuel
- * copyright  2003,2004 MERCIER Denis
- * copyright  2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2003,2004 CREUSE Emmanuel
+ * copyright © 2003,2004 MERCIER Denis
+ * copyright © 2003,2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -49,6 +49,10 @@
 #include <stdlib.h>
 #endif
 
+#if !defined(__COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__VECTORS_H)
 #include "MOL++/vectors.h"
 #endif
@@ -494,8 +498,8 @@ int test_matrix (int detail)
   cout << endl;
 
   cout << "============================================================== \n";
-  if (result) cout<< "                    matrix test passed \n";
-  else cout << "                    matrix test failed \n";
+  if (result) cout << green << "                      matrix test passed" << reset;
+  else cout << red << "                      matrix test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
