@@ -1,14 +1,14 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.0.0                   *
+ *                   GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2004,2005 LAGOUCHE Sophie
  * copyright © 2004,2005 CREUSE Emmanuel
  * copyright © 2006 FACHE Damien
- * copyright © 2006,2007,2008 COLLARD Christophe
- * copyright © 2004,2005,2006,2007,2008 Laboratoire de Physique et Mécanique des Matériaux (LPMM - UMR 7554)
- * copyright © 2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -49,6 +49,10 @@
 #include <stdlib.h>
 #endif
 
+#if !defined(__COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__VECTORS_H)
 #include "MOL++/vectors.h"
 #endif
@@ -158,13 +162,13 @@ int test_spmatrix (int detail)
 
   // with spmatrix
   spmatrix<double> M3(4,5,3), M4(3,5,3), M5(4,4,3), M6(4,5,2);
-  M3(1,1) = 1.0;
+  M3(1,1) = 1;
   M3(1,2) = 2.53;
   M3(2,1) = 2.53;
   M3(3,1) = 87.54;
   M3(3,2) = 87.54;
   M3(3,3) = 87.54;
-  M3(4,4) = 1.0;
+  M3(4,4) = 1;
   if (detail) affiche("operator == spmat/spmat", (M == M3) && (M == M) && !(M == M4) && !(M == M5) && !(M == M6));
   else result *= ((M == M3) && (M == M) && !(M == M4) && !(M == M5) && !(M == M6));
 
@@ -1048,8 +1052,8 @@ int test_spmatrix (int detail)
   cout << endl;
 
   cout << "============================================================== \n";
-  if (result) cout<< "                     spmatrix test passed \n";
-  else cout << "                     spmatrix test failed \n";
+  if (result) cout << green << "                     spmatrix test passed" << reset;
+  else cout << red << "                     spmatrix test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
