@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.0.0                   *
+ *	             GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2004,2005,2006,2007,2008 COLLARD Christophe
- * copyright  2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -47,6 +47,10 @@
 #include <stdlib.h>
 #endif
 
+#if !defined(__COLORS_H)
+#include "colors.h"
+#endif
+
 #if !defined(__VECTORS_H)
 #include "MOL++/vectors.h"
 #endif
@@ -249,6 +253,9 @@ int test_tensor2 (int detail)
   if (detail) affiche ("operator |", (a|e)==sum);
   else result *= ((a|e)==sum);
 
+  if (detail) affiche ("operator ||", (a||e)==sum);
+  else result *= ((a||e)==sum);
+
   tensor2<float> mvv(7,5);
   mvv(1,1) = -3; mvv(2,1) = -15; mvv(3,1) = -21; mvv(4,1) = -30; mvv(5,1) = 6; mvv(6,1) = -9; mvv(7,1) = -63;
   mvv(1,3) = 5; mvv(2,3) = 25; mvv(3,3) = 35; mvv(4,3) = 50; mvv(5,3) = -10; mvv(6,3) = 15; mvv(7,3) = 105;
@@ -458,8 +465,8 @@ int test_tensor2 (int detail)
   cout << endl;
 
   cout << "============================================================== \n";
-  if (result) cout<< "                 2nd order tensor test passed \n";
-  else cout << "                 2nd order tensor test failed \n";
+  if (result) cout << green << "                 2nd order tensor test passed" << reset;
+  else cout << red << "                 2nd order tensor test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
