@@ -1,11 +1,11 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.0.0                   *
+ *                   GNU/linux version 2.2.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2003,2004,2005,2006,2007,2008 COLLARD Christophe
- * copyright  2003,2004,2005,2006,2007,2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
- * copyright  2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
+ * copyright © 2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
+ * copyright © 2003,2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
+ * copyright © 2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
  ***************************************************************/
 
 /*
@@ -318,8 +318,8 @@ int test_tensor3 (int detail)
   cout << endl;  
 
   cout << "============================================================== \n";
-  if (result) cout<< "               3rd order tensor test passed \n";
-  else cout << "               3rd order tensor test failed \n";
+  if (result) cout << green << "               3rd order tensor test passed" << reset;
+  else cout << red << "               3rd order tensor test failed" << reset;
   cout << "============================================================== \n";
 
   return result;
